@@ -10,11 +10,14 @@ PosteriorDraw <- function(mdObj, x, n = 1, ...){
   UseMethod("PosteriorDraw", mdObj)
 }
 
-PosteriorDraw.nonconjugate <- function(mdObj, x, n = 1, start_pos, ...) {
+#' @export
+PosteriorDraw.nonconjugate <- function(mdObj, x, n = 1, ...) {
 
-  if (missing(start_pos)) {
+  if (missing(...)) {
     ### This might need a try catch for models that don't have a penalised likelihood.
     start_pos <- PenalisedLikelihood(mdObj, x)
+  } else {
+    start_pos <- list(...)$start_pos
   }
 
   mh_result <- MetropolisHastings(mdObj, x, start_pos, no_draws = n)
