@@ -12,8 +12,9 @@ weighted_function_generator <- function(func, weights, params) {
 
   weightedFunc <- function(y) {
 
-    if (class(y) == "matrix"){
+    if (class(y) %in% c("matrix", "data.frame")){
       out <- numeric(nrow(y))
+      y <- as.matrix(y)
     }
     else{
       out <- numeric(length(y))
